@@ -8,7 +8,6 @@
 */
 #include "drm_abstract_output.h"
 #include "core/renderbackend.h"
-#include "core/renderloop_p.h"
 #include "drm_backend.h"
 #include "drm_gpu.h"
 #include "drm_layer.h"
@@ -18,7 +17,7 @@ namespace KWin
 
 DrmAbstractOutput::DrmAbstractOutput(DrmGpu *gpu)
     : Output(gpu->platform())
-    , m_renderLoop(std::make_unique<RenderLoop>())
+    , m_renderLoop(std::make_unique<RenderLoop>(this))
     , m_gpu(gpu)
 {
 }
