@@ -40,7 +40,7 @@ static const QMap<uint32_t, QList<uint64_t>> legacyCursorFormats = {{DRM_FORMAT_
 
 DrmPipeline::DrmPipeline(DrmConnector *conn)
     : m_connector(conn)
-    , m_commitThread(std::make_unique<DrmCommitThread>(conn->connectorName()))
+    , m_commitThread(std::make_unique<DrmCommitThread>(conn->gpu(), conn->connectorName()))
 {
     QObject::connect(m_commitThread.get(), &DrmCommitThread::commitFailed, [this]() {
         if (m_output) {
@@ -118,7 +118,7 @@ DrmPipeline::Error DrmPipeline::commitPipelines(const QList<DrmPipeline *> &pipe
     if (pipelines[0]->gpu()->atomicModeSetting()) {
         return commitPipelinesAtomic(pipelines, mode, unusedObjects);
     } else {
-        return commitPipelinesLegacy(pipelines, mode);
+        return commitPipelinesLegacy(pipelines, mode, unusedObjects);
     }
 }
 
@@ -264,8 +264,14 @@ DrmPipeline::Error DrmPipeline::prepareAtomicPresentation(DrmAtomicCommit *commi
     return Error::None;
 }
 
+static const bool s_vrrCursorWorkaround = qEnvironmentVariableIntValue("KWIN_DRM_NO_VRR_CURSOR_WORKAROUND") == 0;
+
 void DrmPipeline::prepareAtomicCursor(DrmAtomicCommit *commit)
 {
+    if (s_vrrCursorWorkaround && m_pending.presentationMode != PresentationMode::VSync) {
+        // trigger a pageflip on the primary plane, as a workaround for https://gitlab.freedesktop.org/drm/amd/-/issues/3034
+        commit->addProperty(m_pending.crtc->primaryPlane()->srcX, 0);
+    }
     auto plane = m_pending.crtc->cursorPlane();
     const auto layer = cursorLayer();
     plane->set(commit, QPoint(0, 0), gpu()->cursorSize(), QRect(layer->position().toPoint(), gpu()->cursorSize()));
