@@ -57,7 +57,7 @@ DrmPipeline::Error DrmPipeline::legacyModeset()
     return Error::None;
 }
 
-DrmPipeline::Error DrmPipeline::commitPipelinesLegacy(const QList<DrmPipeline *> &pipelines, CommitMode mode)
+DrmPipeline::Error DrmPipeline::commitPipelinesLegacy(const QList<DrmPipeline *> &pipelines, CommitMode mode, const QList<DrmObject *> &unusedObjects)
 {
     Error err = Error::None;
     for (const auto &pipeline : pipelines) {
@@ -79,6 +79,11 @@ DrmPipeline::Error DrmPipeline::commitPipelinesLegacy(const QList<DrmPipeline *>
                 pipeline->pageFlipped(std::chrono::steady_clock::now().time_since_epoch(), PageflipType::Normal, PresentationMode::VSync);
             }
         }
+        for (const auto &obj : unusedObjects) {
+            if (auto crtc = dynamic_cast<DrmCrtc *>(obj)) {
+                drmModeSetCrtc(pipelines.front()->gpu()->fd(), crtc->id(), 0, 0, 0, nullptr, 0, nullptr);
+            }
+        }
     }
     return err;
 }
@@ -108,6 +113,17 @@ DrmPipeline::Error DrmPipeline::applyPendingChangesLegacy()
         if (m_connector->scalingMode.isValid() && m_connector->scalingMode.hasEnum(DrmConnector::ScalingMode::None)) {
             m_connector->scalingMode.setEnumLegacy(DrmConnector::ScalingMode::None);
         }
+        if (m_connector->hdrMetadata.isValid()) {
+            const auto blob = createHdrMetadata(m_pending.colorDescription.transferFunction());
+            m_connector->hdrMetadata.setPropertyLegacy(blob ? blob->blobId() : 0);
+        }
+        if (m_connector->colorspace.isValid()) {
+            if (m_pending.colorDescription.colorimetry() == NamedColorimetry::BT2020) {
+                m_connector->colorspace.setEnumLegacy(DrmConnector::Colorspace::BT2020_RGB);
+            } else {
+                m_connector->colorspace.setEnumLegacy(DrmConnector::Colorspace::Default);
+            }
+        }
         const auto currentModeContent = m_pending.crtc->queryCurrentMode();
         if (m_pending.crtc != m_next.crtc || *m_pending.mode != currentModeContent) {
             qCDebug(KWIN_DRM) << "Using legacy path to set mode" << m_pending.mode->nativeMode()->name;
