@@ -366,6 +366,8 @@ void QuickSceneEffect::activateView(QuickSceneView *view)
 // Screen views are repainted just before kwin performs its compositing cycle to avoid stalling for vblank
 void QuickSceneEffect::prePaintScreen(ScreenPrePaintData &data, std::chrono::milliseconds presentTime)
 {
+    data.mask |= PAINT_SCREEN_TRANSFORMED;
+
     if (effects->waylandDisplay()) {
         const auto it = d->views.find(data.screen);
         if (it != d->views.end() && it->second->isDirty()) {
@@ -433,6 +435,8 @@ void QuickSceneEffect::addScreen(Output *screen)
             connect(view.get(), &QuickSceneView::renderRequested, view.get(), &QuickSceneView::scheduleRepaint);
             connect(view.get(), &QuickSceneView::sceneChanged, view.get(), &QuickSceneView::scheduleRepaint);
             view->scheduleRepaint();
+            // view is returned via invokables elsewhere
+            QJSEngine::setObjectOwnership(view.get(), QJSEngine::CppOwnership);
             d->views[screen] = std::move(view);
         } else if (incubator->isError()) {
             qCWarning(LIBKWINEFFECTS) << "Could not create a view for QML file" << d->delegate->url();
