@@ -145,7 +145,7 @@ QSizeF InternalWindow::maxSize() const
     return m_handle->maximumSize();
 }
 
-NET::WindowType InternalWindow::windowType(bool direct) const
+NET::WindowType InternalWindow::windowType() const
 {
     return NET::Normal;
 }
@@ -476,6 +476,7 @@ void InternalWindow::setCaption(const QString &caption)
     const QString oldCaptionSuffix = m_captionSuffix;
     updateCaption();
 
+    Q_EMIT captionNormalChanged();
     if (m_captionSuffix == oldCaptionSuffix) {
         Q_EMIT captionChanged();
     }
