@@ -704,12 +704,6 @@ void RulesModel::populateRuleList()
                          i18n("Closeable"), i18n("Appearance & Fixes"),
                          QIcon::fromTheme("dialog-close")));
 
-    auto type = addRule(new RuleItem(QLatin1String("type"),
-                                     RulePolicy::ForceRule, RuleItem::Option,
-                                     i18n("Set window type"), i18n("Appearance & Fixes"),
-                                     QIcon::fromTheme("window-duplicate")));
-    type->setOptionsData(windowTypesModelData());
-
     addRule(new RuleItem(QLatin1String("desktopfile"),
                          RulePolicy::SetRule, RuleItem::String,
                          i18n("Desktop file name"), i18n("Appearance & Fixes"),
@@ -719,6 +713,12 @@ void RulesModel::populateRuleList()
                          RulePolicy::ForceRule, RuleItem::Boolean,
                          i18n("Block compositing"), i18n("Appearance & Fixes"),
                          QIcon::fromTheme("composite-track-on")));
+
+    auto layer = addRule(new RuleItem(QLatin1String("layer"),
+                                      RulePolicy::ForceRule, RuleItem::Option,
+                                      i18n("Layer"), i18n("Appearance & Fixes"),
+                                      QIcon::fromTheme("view-sort")));
+    layer->setOptionsData(layerModelData());
 }
 
 const QHash<QString, QString> RulesModel::x11PropertyHash()
@@ -738,9 +738,9 @@ const QHash<QString, QString> RulesModel::x11PropertyHash()
         {"skipTaskbar", "skiptaskbar"},
         {"skipPager", "skippager"},
         {"skipSwitcher", "skipswitcher"},
-        {"type", "type"},
         {"desktopFile", "desktopfile"},
         {"desktops", "desktops"},
+        {"layer", "layer"},
     };
     return propertyToRule;
 };
@@ -911,6 +911,23 @@ QList<OptionsModel::Data> RulesModel::colorSchemesModelData() const
     return modelData;
 }
 
+QList<OptionsModel::Data> RulesModel::layerModelData() const
+{
+    static const auto modelData = QList<OptionsModel::Data>{
+        {DesktopLayer, i18n("Desktop")},
+        {BelowLayer, i18n("Below")},
+        {NormalLayer, i18n("Normal")},
+        {AboveLayer, i18n("Above")},
+        {NotificationLayer, i18n("Notification")},
+        {ActiveLayer, i18n("Fullscreen")},
+        {PopupLayer, i18n("Popup")},
+        {CriticalNotificationLayer, i18n("Critical Notification")},
+        {OnScreenDisplayLayer, i18n("OSD")},
+        {OverlayLayer, i18n("Overlay")},
+    };
+    return modelData;
+}
+
 void RulesModel::detectWindowProperties(int miliseconds)
 {
     QTimer::singleShot(miliseconds, this, &RulesModel::selectX11Window);
