@@ -61,33 +61,12 @@ public:
     {
         return m_failed;
     }
-    /**
-     * @brief Whether the backend uses direct rendering.
-     *
-     * Some OpenGLScene modes require direct rendering. E.g. the OpenGL 2 should not be used
-     * if direct rendering is not supported by the Scene.
-     *
-     * @return bool @c true if the GL context is direct, @c false if indirect
-     */
-    bool isDirectRendering() const
-    {
-        return m_directRendering;
-    }
 
     bool supportsBufferAge() const
     {
         return m_haveBufferAge;
     }
 
-    bool supportsPartialUpdate() const
-    {
-        return m_havePartialUpdate;
-    }
-    bool supportsSwapBuffersWithDamage() const
-    {
-        return m_haveSwapBuffersWithDamage;
-    }
-
     bool supportsNativeFence() const
     {
         return m_haveNativeFence;
@@ -116,7 +95,7 @@ public:
      */
     void copyPixels(const QRegion &region, const QSize &screenSize);
 
-    virtual std::shared_ptr<GLTexture> textureForOutput(Output *output) const;
+    virtual std::pair<std::shared_ptr<GLTexture>, ColorDescription> textureForOutput(Output *output) const;
 
 protected:
     /**
@@ -128,35 +107,12 @@ protected:
      * @param reason The reason why the initialization failed.
      */
     void setFailed(const QString &reason);
-    /**
-     * @brief Sets whether the OpenGL context is direct.
-     *
-     * Should be called by the concrete subclass once it is determined whether the OpenGL context is
-     * direct or indirect.
-     * If the subclass does not call this method, the backend defaults to @c false.
-     *
-     * @param direct @c true if the OpenGL context is direct, @c false if indirect
-     */
-    void setIsDirectRendering(bool direct)
-    {
-        m_directRendering = direct;
-    }
 
     void setSupportsBufferAge(bool value)
     {
         m_haveBufferAge = value;
     }
 
-    void setSupportsPartialUpdate(bool value)
-    {
-        m_havePartialUpdate = value;
-    }
-
-    void setSupportsSwapBuffersWithDamage(bool value)
-    {
-        m_haveSwapBuffersWithDamage = value;
-    }
-
     void setSupportsNativeFence(bool value)
     {
         m_haveNativeFence = value;
@@ -173,19 +129,10 @@ protected:
     }
 
 private:
-    /**
-     * @brief Whether direct rendering is used, defaults to @c false.
-     */
-    bool m_directRendering;
     /**
      * @brief Whether the backend supports GLX_EXT_buffer_age / EGL_EXT_buffer_age.
      */
     bool m_haveBufferAge;
-    /**
-     * @brief Whether the backend supports EGL_KHR_partial_update
-     */
-    bool m_havePartialUpdate = false;
-    bool m_haveSwapBuffersWithDamage = false;
     /**
      * @brief Whether the backend supports EGL_ANDROID_native_fence_sync.
      */
