@@ -139,7 +139,7 @@ void MouseClickEffect::postPaintScreen()
     repaint();
 }
 
-float MouseClickEffect::computeRadius(const MouseEvent *click, int ring)
+float MouseClickEffect::computeRadius(const MouseClickMouseEvent *click, int ring)
 {
     float ringDistance = m_ringLife / (m_ringCount * 3);
     if (click->m_press) {
@@ -148,7 +148,7 @@ float MouseClickEffect::computeRadius(const MouseEvent *click, int ring)
     return ((m_ringLife - click->m_time - ringDistance * ring) / m_ringLife) * m_ringMaxSize;
 }
 
-float MouseClickEffect::computeAlpha(const MouseEvent *click, int ring)
+float MouseClickEffect::computeAlpha(const MouseClickMouseEvent *click, int ring)
 {
     float ringDistance = m_ringLife / (m_ringCount * 3);
     return (m_ringLife - (float)click->m_time - ringDistance * (ring)) / m_ringLife;
@@ -162,16 +162,16 @@ void MouseClickEffect::slotMouseChanged(const QPointF &pos, const QPointF &,
         return;
     }
 
-    std::unique_ptr<MouseEvent> m;
+    std::unique_ptr<MouseClickMouseEvent> m;
     int i = BUTTON_COUNT;
     while (--i >= 0) {
         MouseButton *b = m_buttons[i].get();
         if (isPressed(b->m_button, buttons, oldButtons)) {
-            m = std::make_unique<MouseEvent>(i, pos.toPoint(), 0, createEffectFrame(pos.toPoint(), b->m_labelDown), true);
+            m = std::make_unique<MouseClickMouseEvent>(i, pos.toPoint(), 0, createEffectFrame(pos.toPoint(), b->m_labelDown), true);
             break;
         } else if (isReleased(b->m_button, buttons, oldButtons) && (!b->m_isPressed || b->m_time > m_ringLife)) {
             // we might miss a press, thus also check !b->m_isPressed, bug #314762
-            m = std::make_unique<MouseEvent>(i, pos.toPoint(), 0, createEffectFrame(pos.toPoint(), b->m_labelUp), false);
+            m = std::make_unique<MouseClickMouseEvent>(i, pos.toPoint(), 0, createEffectFrame(pos.toPoint(), b->m_labelUp), false);
             break;
         }
         b->setPressed(b->m_button & buttons);
