@@ -59,10 +59,11 @@ void RegionScreenCastSource::updateOutput(Output *output)
 
         ShaderBinder shaderBinder(ShaderTrait::MapTexture | ShaderTrait::TransformColorspace);
         QMatrix4x4 projectionMatrix;
+        projectionMatrix.scale(1, -1);
         projectionMatrix.ortho(m_region);
         projectionMatrix.translate(outputGeometry.left(), outputGeometry.top());
 
-        shaderBinder.shader()->setUniform(GLShader::ModelViewProjectionMatrix, projectionMatrix);
+        shaderBinder.shader()->setUniform(GLShader::Mat4Uniform::ModelViewProjectionMatrix, projectionMatrix);
         shaderBinder.shader()->setColorspaceUniformsToSRGB(colorDescription);
 
         outputTexture->render(outputGeometry.size());
@@ -82,6 +83,7 @@ void RegionScreenCastSource::ensureTexture()
         if (!m_renderedTexture) {
             return;
         }
+        m_renderedTexture->setContentTransform(OutputTransform::FlipY);
         m_renderedTexture->setFilter(GL_LINEAR);
         m_renderedTexture->setWrapMode(GL_CLAMP_TO_EDGE);
 
@@ -105,7 +107,7 @@ void RegionScreenCastSource::render(GLFramebuffer *target)
     QMatrix4x4 projectionMatrix;
     projectionMatrix.scale(1, -1);
     projectionMatrix.ortho(QRect(QPoint(), target->size()));
-    shader->setUniform(GLShader::ModelViewProjectionMatrix, projectionMatrix);
+    shader->setUniform(GLShader::Mat4Uniform::ModelViewProjectionMatrix, projectionMatrix);
 
     m_renderedTexture->render(target->size());
 
