@@ -244,6 +244,7 @@ void ZoomEffect::reconfigure(ReconfigureFlags)
 
 void ZoomEffect::prePaintScreen(ScreenPrePaintData &data, std::chrono::milliseconds presentTime)
 {
+    data.mask |= PAINT_SCREEN_TRANSFORMED;
     if (zoom != target_zoom) {
         int time = 0;
         if (lastPresentTime.count()) {
@@ -326,25 +327,42 @@ void ZoomEffect::paintScreen(const RenderTarget &renderTarget, const RenderViewp
         break;
     case MouseTrackingPush: {
         // touching an edge of the screen moves the zoom-area in that direction.
-        int x = cursorPoint.x() * zoom - prevPoint.x() * (zoom - 1.0);
-        int y = cursorPoint.y() * zoom - prevPoint.y() * (zoom - 1.0);
-        int threshold = 4;
+        const int x = cursorPoint.x() * zoom - prevPoint.x() * (zoom - 1.0);
+        const int y = cursorPoint.y() * zoom - prevPoint.y() * (zoom - 1.0);
+        const int threshold = 4;
+        const QRectF currScreen = effects->screenAt(QPoint(x, y))->geometry();
+
+        // bounds of the screen the cursor's on
+        const int screenTop = currScreen.top();
+        const int screenLeft = currScreen.left();
+        const int screenRight = currScreen.right();
+        const int screenBottom = currScreen.bottom();
+        const int screenCenterX = currScreen.center().x();
+        const int screenCenterY = currScreen.center().y();
+
+        // figure out whether we have adjacent displays in all 4 directions
+        // We pan within the screen in directions where there are no adjacent screens.
+        const bool adjacentLeft = screenExistsAt(QPoint(screenLeft - 1, screenCenterY));
+        const bool adjacentRight = screenExistsAt(QPoint(screenRight + 1, screenCenterY));
+        const bool adjacentTop = screenExistsAt(QPoint(screenCenterX, screenTop - 1));
+        const bool adjacentBottom = screenExistsAt(QPoint(screenCenterX, screenBottom + 1));
+
         xMove = yMove = 0;
-        if (x < threshold) {
-            xMove = (x - threshold) / zoom;
-        } else if (x + threshold > screenSize.width()) {
-            xMove = (x + threshold - screenSize.width()) / zoom;
+        if (x < screenLeft + threshold && !adjacentLeft) {
+            xMove = (x - threshold - screenLeft) / zoom;
+        } else if (x > screenRight - threshold && !adjacentRight) {
+            xMove = (x + threshold - screenRight) / zoom;
         }
-        if (y < threshold) {
-            yMove = (y - threshold) / zoom;
-        } else if (y + threshold > screenSize.height()) {
-            yMove = (y + threshold - screenSize.height()) / zoom;
+        if (y < screenTop + threshold && !adjacentTop) {
+            yMove = (y - threshold - screenTop) / zoom;
+        } else if (y > screenBottom - threshold && !adjacentBottom) {
+            yMove = (y + threshold - screenBottom) / zoom;
         }
         if (xMove) {
-            prevPoint.setX(std::max(0, std::min(screenSize.width(), prevPoint.x() + xMove)));
+            prevPoint.setX(prevPoint.x() + xMove);
         }
         if (yMove) {
-            prevPoint.setY(std::max(0, std::min(screenSize.height(), prevPoint.y() + yMove)));
+            prevPoint.setY(prevPoint.y() + yMove);
         }
         xTranslation = -int(prevPoint.x() * (zoom - 1.0));
         yTranslation = -int(prevPoint.y() * (zoom - 1.0));
@@ -379,7 +397,7 @@ void ZoomEffect::paintScreen(const RenderTarget &renderTarget, const RenderViewp
         matrix.scale(zoom, zoom);
         matrix.translate(offscreen.viewport.x() * scale, offscreen.viewport.y() * scale);
 
-        shader->setUniform(GLShader::ModelViewProjectionMatrix, viewport.projectionMatrix() * matrix);
+        shader->setUniform(GLShader::Mat4Uniform::ModelViewProjectionMatrix, viewport.projectionMatrix() * matrix);
 
         offscreen.texture->render(offscreen.viewport.size() * scale);
     }
@@ -406,7 +424,7 @@ void ZoomEffect::paintScreen(const RenderTarget &renderTarget, const RenderViewp
             s->setColorspaceUniformsFromSRGB(renderTarget.colorDescription());
             QMatrix4x4 mvp = viewport.projectionMatrix();
             mvp.translate(p.x() * scale, p.y() * scale);
-            s->setUniform(GLShader::ModelViewProjectionMatrix, mvp);
+            s->setUniform(GLShader::Mat4Uniform::ModelViewProjectionMatrix, mvp);
             cursorTexture->render(cursorSize * scale);
             ShaderManager::instance()->popShader();
             glDisable(GL_BLEND);
@@ -624,6 +642,12 @@ qreal ZoomEffect::targetZoom() const
     return target_zoom;
 }
 
+bool ZoomEffect::screenExistsAt(const QPoint &point) const
+{
+    const Output *output = effects->screenAt(point);
+    return output && output->geometry().contains(point);
+}
+
 } // namespace
 
 #include "moc_zoom.cpp"
