@@ -8,6 +8,8 @@
 #include "core/pixelgrid.h"
 #include "scene/scene.h"
 
+using namespace std::chrono_literals;
+
 namespace KWin
 {
 
@@ -107,8 +109,7 @@ void SurfaceItem::addDamage(const QRegion &region)
         if (m_lastDamageTimeDiffs.size() > 100) {
             m_lastDamageTimeDiffs.pop_front();
         }
-        const auto average = std::accumulate(m_lastDamageTimeDiffs.begin(), m_lastDamageTimeDiffs.end(), std::chrono::nanoseconds::zero()) / m_lastDamageTimeDiffs.size();
-        m_refreshRate = std::chrono::nanoseconds(1'000'000'000) / average;
+        m_frameTimeEstimation = std::accumulate(m_lastDamageTimeDiffs.begin(), m_lastDamageTimeDiffs.end(), 0ns) / m_lastDamageTimeDiffs.size();
     }
     m_lastDamage = std::chrono::steady_clock::now();
     m_damage += region;
@@ -259,14 +260,13 @@ void SurfaceItem::freeze()
 {
 }
 
-double SurfaceItem::refreshRateEstimation() const
+std::chrono::nanoseconds SurfaceItem::frameTimeEstimation() const
 {
     if (m_lastDamage) {
         const auto diff = std::chrono::steady_clock::now() - *m_lastDamage;
-        const double refreshRate = std::chrono::nanoseconds(1'000'000'000) / diff;
-        return std::min(m_refreshRate, refreshRate);
+        return std::max(m_frameTimeEstimation, diff);
     } else {
-        return m_refreshRate;
+        return m_frameTimeEstimation;
     }
 }
 
