@@ -41,7 +41,7 @@ public:
     QRegion opaque() const override;
 
 private Q_SLOTS:
-    void handleBufferGeometryChanged(const QRectF &old);
+    void handleBufferGeometryChanged();
     void handleShapeChanged();
 
 protected:
