@@ -238,12 +238,7 @@ QRegion WorkspaceScene::prePaint(SceneDelegate *delegate)
     const std::chrono::milliseconds presentTime =
         std::chrono::duration_cast<std::chrono::milliseconds>(renderLoop->nextPresentationTimestamp());
 
-    if (Q_UNLIKELY(presentTime < m_expectedPresentTimestamp)) {
-        qCDebug(KWIN_CORE,
-                "Provided presentation timestamp is invalid: %lld (current: %lld)",
-                static_cast<long long>(presentTime.count()),
-                static_cast<long long>(m_expectedPresentTimestamp.count()));
-    } else {
+    if (presentTime > m_expectedPresentTimestamp) {
         m_expectedPresentTimestamp = presentTime;
     }
 
@@ -330,7 +325,7 @@ void WorkspaceScene::preparePaintSimpleScreen()
 
             const DecorationItem *decorationItem = windowItem->decorationItem();
             if (decorationItem) {
-                data.opaque |= decorationItem->mapToGlobal(decorationItem->opaque());
+                data.opaque += decorationItem->mapToGlobal(decorationItem->opaque());
             }
         }
 
@@ -372,7 +367,7 @@ void WorkspaceScene::postPaint()
 void WorkspaceScene::paint(const RenderTarget &renderTarget, const QRegion &region)
 {
     Output *output = kwinApp()->operationMode() == Application::OperationMode::OperationModeX11 ? nullptr : painted_screen;
-    RenderViewport viewport(output ? output->fractionalGeometry() : workspace()->geometry(), output ? output->scale() : 1, renderTarget);
+    RenderViewport viewport(output ? output->geometryF() : workspace()->geometry(), output ? output->scale() : 1, renderTarget);
 
     m_renderer->beginFrame(renderTarget, viewport);
 
