@@ -8,11 +8,11 @@
 */
 #pragma once
 
-#include "libkwineffects/kwinglobals.h"
-#include "libkwineffects/kwinxcb.h"
-#include "libkwineffects/version.h"
+#include "effect/globals.h"
+#include "effect/xcb.h"
 #include "main.h"
 #include "utils/c_ptr.h"
+#include "utils/version.h"
 
 #include <QList>
 #include <QRect>
